@@ -298,7 +298,7 @@ LibPinyinBackEnd::exportPinyinDictionary (const char *filename)
         gchar * phrase = NULL; gchar * pinyin = NULL;
         gint count = -1;
 
-        g_assert (pinyin_iterator_get_next_phrase (iter, &phrase, &pinyin, &count));
+        check_result (pinyin_iterator_get_next_phrase (iter, &phrase, &pinyin, &count));
 
         if (-1 == count) /* skip output the default count. */
             fprintf (dictfile, "%s %s\n", phrase, pinyin);
@@ -353,6 +353,16 @@ LibPinyinBackEnd::rememberUserInput (pinyin_instance_t *instance,
     return TRUE;
 }
 
+gboolean
+LibPinyinBackEnd::rememberCloudInput (pinyin_instance_t *instance,
+                                      const gchar *pinyin,
+                                      const gchar *phrase)
+{
+    pinyin_parse_more_full_pinyins (instance, pinyin);
+    pinyin_remember_user_input (instance, phrase, -1);
+    return TRUE;
+}
+
 gboolean
 LibPinyinBackEnd::timeoutCallback (gpointer data)
 {
