@@ -410,7 +410,9 @@ CloudCandidates::processCandidates (std::vector<EnhancedCandidate> & candidates)
 
     /* search the first non-ngram candidate position */
     for (pos = candidates.begin (); pos != candidates.end (); ++pos) {
-        if (CANDIDATE_NBEST_MATCH != pos->m_candidate_type)
+        if (CANDIDATE_NBEST_MATCH != pos->m_candidate_type &&
+            CANDIDATE_LONGER != pos->m_candidate_type &&
+            CANDIDATE_LONGER_USER != pos->m_candidate_type)
             break;
         m_candidate_cache.insert (pos->m_display_string);
     }
